@@ -836,7 +836,7 @@ styles = {
     "default": ["0", "1", "2"],
     "duration": ["2", "5", "8"],
     "cradek": ["0", "1", "-"],
-    "bar": ["▟█", "▄█", "▄▟"],
+    "bar": ["🬍🬎", "🬋🬎", "🬋🬍"],
     "sextant": ["🬍🬎", "🬋🬎", "🬋🬍", "🬩🬹", "🬋🬹", "🬋🬩"],
 }
 
